@@ -267,9 +267,9 @@ class NonBlockingTLS(PlugIn):
         self.cacerts = cacerts
         self.mycerts = mycerts
         if cipher_list is None:
-            self.cipher_list = 'HIGH:!aNULL:RC4-SHA'
+            self.cipher_list = b'HIGH:!aNULL:RC4-SHA'
         else:
-            self.cipher_list = cipher_list
+            self.cipher_list = cipher_list.encode('ascii')
         if tls_version is None:
             self.tls_version = '1.0'
         else:
@@ -350,7 +350,7 @@ class NonBlockingTLS(PlugIn):
                 cert = ''.join(lines[begin:i+2])
                 try:
                     x509cert = OpenSSL.crypto.load_certificate(
-                            OpenSSL.crypto.FILETYPE_PEM, cert)
+                            OpenSSL.crypto.FILETYPE_PEM, cert.encode('ascii', 'ignore'))
                     cert_store.add_cert(x509cert)
                 except OpenSSL.crypto.Error as exception_obj:
                     if logg:
